/*
 * Copyright 2020 Fluence Labs Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { PeerIdB58 } from './internal/commonTypes';
import Multiaddr from 'multiaddr';

export interface FluenceClient {
    readonly relayPeerId: PeerIdB58;
    readonly selfPeerId: PeerIdB58;
    readonly isConnected: boolean;

    disconnect(): Promise<void>;

    /**
     * Establish a connection to the node. If the connection is already established, disconnect and reregister all services in a new connection.
     *
     * @param multiaddr
     */
    connect(multiaddr: string | Multiaddr): Promise<void>;

    sendScript(script: string, data?: Map<string, any>, ttl?: number): Promise<string>;
}
